# Generated by roxygen2: do not edit by hand

export(read_cru_dt)
export(read_cru_rast)
importFrom(brio,write_file_raw)
importFrom(cli,cli_abort)
importFrom(data.table,"%notin%")
importFrom(data.table,":=")
importFrom(data.table,.BY)
importFrom(data.table,.EACHI)
importFrom(data.table,.GRP)
importFrom(data.table,.I)
importFrom(data.table,.N)
importFrom(data.table,.NGRP)
importFrom(data.table,.SD)
importFrom(data.table,data.table)
importFrom(fs,dir_create)
importFrom(fs,path_dir)
importFrom(fs,path_temp)
importFrom(httr2,req_cache)
importFrom(httr2,req_error)
importFrom(httr2,req_headers)
importFrom(httr2,req_options)
importFrom(httr2,req_perform)
importFrom(httr2,req_retry)
importFrom(httr2,req_user_agent)
importFrom(httr2,request)
importFrom(httr2,resp_body_raw)
importFrom(httr2,resp_status)
