% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/internal-create_dt.R
\name{.drop_source_vars_dt}
\alias{.drop_source_vars_dt}
\title{Remove source vars if not requested}
\usage{
.drop_source_vars_dt(dt, vars)
}
\arguments{
\item{dt}{A data.table object of CRU data containing \code{tmp} and \code{dtr} in order
to calculate tmin and tmax.}

\item{vars}{A named logical vector.}
}
\value{
A data.table with the unrequested var columns removed.
}
\description{
If \code{tmin} or \code{tmax} are requested but \code{tmp} or \code{dtr} are not requested, this
function drops the unrequested vars.
}
