% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getCRUCLdata-package.R
\docType{package}
\name{getCRUCLdata-package}
\alias{getCRUCLdata}
\alias{getCRUCLdata-package}
\title{getCRUCLdata: 'CRU' 'CL' v. 2.0 Climatology Client}
\description{
Provides functions that automate downloading and importing University of East Anglia Climate Research Unit ('CRU') 'CL' v. 2.0 climatology data, facilitates the calculation of minimum temperature and maximum temperature and formats the data into a data.table object or a 'terra' 'SpatRaster' object. 'CRU' 'CL' v. 2.0 data are a gridded climatology of 1961-1990 monthly means released in 2002 and cover all land areas (excluding Antarctica) at 10 arc minutes (0.1666667 degree) resolution. For more information see the description of the data provided by the University of East Anglia Climate Research Unit, \url{https://crudata.uea.ac.uk/cru/data/hrg/tmc/readme.txt}.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://codeberg.org/ropensci/getCRUCLdata}
  \item \url{https://docs.ropensci.org/getCRUCLdata/}
  \item Report bugs at \url{https://codeberg.org/ropensci/getCRUCLdata/issues}
}

}
\author{
\strong{Maintainer}: Adam H. Sparks \email{adamhsparks@gmail.com} (\href{https://orcid.org/0000-0002-0061-8359}{ORCID})

Authors:
\itemize{
  \item Adam H. Sparks \email{adamhsparks@gmail.com} (\href{https://orcid.org/0000-0002-0061-8359}{ORCID})
}

}
\keyword{internal}
