% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/internal-create_dt.R
\name{.add_derived_dt}
\alias{.add_derived_dt}
\title{Add derived temperature values for TMAX and TMIN}
\usage{
.add_derived_dt(dt, vars)
}
\arguments{
\item{dt}{A data.table object of CRU data containing \code{tmp} and \code{dtr} in order
to calculate tmin and tmax.}

\item{vars}{A named logical vector.}
}
\value{
A data.table with tmin and or tmax cols.
}
\description{
Add derived temperature values for TMAX and TMIN
}
